<?php
namespace Teknisa\PLA\Modules\Mymeals\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Planejamento\Entities\Confirmarefe;
use Teknisa\Model\Planejamento\Entities\Compcard;
use Teknisa\Model\Planejamento\Entities\Cardacli;
use Teknisa\Model\Planejamento\Entities\Cardadia;
use Zeedhi\Framework\DataSource;

class Pla02030AprovacaoComensaisService {

    protected $entityManager;
    protected $environment;
    protected $dataSourceManager;

    public function __construct(EntityManager $entityManager, $environment, DataSource\Manager $dataSourceManager)
    {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->dataSourceManager = $dataSourceManager;
    }

    public function iniciaTransacao(){
        $this->entityManager->beginTransaction();
    }

    public function commit(){
        $this->entityManager->commit();
    }

    public function flush(){
        $this->entityManager->flush();
    }

    public function rollback(){
        $this->entityManager->rollback();
    }
    
    public function atualizaCardadia($row){
        $cardadia = $this->entityManager->getRepository('\Teknisa\Model\Planejamento\Entities\Cardadia')
            ->findOneBy(
                array(
                    "nrorg" => $row['NRORG'],
                    "cdfilial" => $row['CDFILIAL'],
                    "nrcardapio" => $row['NRCARDAPIO']
                )
            );
            
        if($cardadia instanceof Cardadia){
            $cardadia->setNrorg($row['NRORG']);
            $cardadia->setCdfilial($row['CDFILIAL']);
            $cardadia->setNrcardapio($row['NRCARDAPIO']);
            $cardadia->setQtcomesticar($row['QTCOMESTICAR']);
            $cardadia->setQtcliesticar($row['QTCLIESTICAR']);
            $cardadia->setQtfunesticar($row['QTFUNESTICAR']);
            $cardadia->setQtdoaesticar($row['QTDOAESTICAR']);
            $cardadia->setQtestiturno1($row['QTESTITURNO1']);
            $cardadia->setQtestiturno2($row['QTESTITURNO2']);
            $cardadia->setQtestiturno3($row['QTESTITURNO3']);
            $cardadia->setQtestiturno4($row['QTESTITURNO4']);
                
            $this->entityManager->persist($cardadia);
        }
    }
    
    public function atualizaComensaisCardacli($row){
        $cardacli = $this->entityManager->getRepository('\Teknisa\Model\Planejamento\Entities\Cardacli')
            ->findOneBy(
                array(
                    "nrorg" => $row['NRORG'],
                    "cdcliente" => $row['CDCLIENTE'],
                    "nrcardapio" => $row['NRCARDAPIO']
                )
            );
                
        if($cardacli instanceof Cardadia){
            $cardacli->setNrorg($row['NRORG']);
            $cardacli->setNrcardapio($row['NRCARDAPIO']);
            $cardacli->setCdcliente($row['CDCLIENTE']);
            $cardacli->setCddestfili($row['CDDESTFILI']);
            $cardacli->setQtcomealterada($row['QTCOMEALTERADA']);
                
            $this->entityManager->persist($cardacli);
        }
    }
    
    public function getCardadiaAprov($params){
        try{
            return $this->entityManager->getRepository('\Teknisa\Model\Planejamento\Entities\Cardadia')
                ->findOneBy(
                    array(
                        "nrorg" => $params['NRORG'],
                        "cdfilial" => $params['CDFILIAL'],
                        "nrcardapio" => $params['NRCARDAPIO']
                    )
                );
        }catch(\Exception $e){
            throw $e;
        }
    }
    
    public function getAlteracoesCardapio($params){
        $sql = "SELECT CO.* FROM CONFIRMAREFE CO INNER JOIN(SELECT NRORG, CDFILIAL, CDSERVFILI, NRCARDAPIO, DTCARDAPIO, MAX(NRCONFIRMAREFE) AS NRCONFIRMAREFE FROM CONFIRMAREFE WHERE NRORG = :NRORG AND CDFILIAL = :CDFILIAL AND CDSERVFILI = :CDSERVFILI AND TO_CHAR(DTCARDAPIO,'DD/MM/YYYY') = :DTCARDAPIO AND NRCARDAPIO = :NRCARDAPIO AND CDCLIENTE IS NULL AND CDDESTFILI IS NULL AND CDTURNO IS NULL AND IDQTDEAPROVADA = :IDQTDEAPROVADA GROUP BY NRORG, CDFILIAL, CDSERVFILI, NRCARDAPIO, DTCARDAPIO) C ON C.NRORG = CO.NRORG AND C.NRCONFIRMAREFE = CO.NRCONFIRMAREFE ORDER BY CO.NRCONFIRMAREFE, CO.CDFILIAL, CO.CDSERVFILI, CO.NRCARDAPIO, CO.DTCARDAPIO";
        try {
            return $this->entityManager->getConnection()->fetchAll($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getAlteracoesTurno($params){
        $sql = "SELECT CO.* FROM CONFIRMAREFE CO INNER JOIN(SELECT NRORG, CDFILIAL, CDSERVFILI, NRCARDAPIO, DTCARDAPIO, CDTURNO, MAX(NRCONFIRMAREFE) AS NRCONFIRMAREFE FROM CONFIRMAREFE WHERE NRORG = :NRORG AND CDFILIAL = :CDFILIAL AND CDSERVFILI = :CDSERVFILI AND NRCARDAPIO = :NRCARDAPIO AND TO_CHAR(DTCARDAPIO,'DD/MM/YYYY') = :DTCARDAPIO AND CDCLIENTE IS NULL AND CDDESTFILI IS NULL AND CDTURNO IS NOT NULL AND IDQTDEAPROVADA = :IDQTDEAPROVADA GROUP BY NRORG, CDFILIAL, CDSERVFILI, NRCARDAPIO, DTCARDAPIO, CDTURNO) C ON C.NRORG = CO.NRORG AND C.NRCONFIRMAREFE = CO.NRCONFIRMAREFE ORDER BY CO.NRCONFIRMAREFE, CO.CDFILIAL, CO.CDSERVFILI, CO.NRCARDAPIO, CO.DTCARDAPIO";
        try {
            return $this->entityManager->getConnection()->fetchAll($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getAlteracoesPontoEntrega($params){
        $sql = "SELECT CO.* FROM CONFIRMAREFE CO INNER JOIN(SELECT NRORG, CDFILIAL, CDSERVFILI, NRCARDAPIO, DTCARDAPIO, CDCLIENTE, CDDESTFILI, MAX(NRCONFIRMAREFE) AS NRCONFIRMAREFE FROM CONFIRMAREFE WHERE NRORG = :NRORG AND CDFILIAL = :CDFILIAL AND CDSERVFILI = :CDSERVFILI AND NRCARDAPIO = :NRCARDAPIO AND TO_CHAR(DTCARDAPIO,'DD/MM/YYYY') = :DTCARDAPIO AND CDCLIENTE IS NOT NULL AND CDDESTFILI IS NOT NULL AND CDTURNO IS NULL AND IDQTDEAPROVADA = :IDQTDEAPROVADA GROUP BY NRORG, CDFILIAL, CDSERVFILI, NRCARDAPIO, DTCARDAPIO, CDCLIENTE, CDDESTFILI) C ON C.NRORG = CO.NRORG AND C.NRCONFIRMAREFE = CO.NRCONFIRMAREFE ORDER BY CO.NRCONFIRMAREFE, CO.CDFILIAL, CO.CDSERVFILI, CO.NRCARDAPIO, CO.DTCARDAPIO";
        try {
            return $this->entityManager->getConnection()->fetchAll($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function insereConfirmarefe($row){
        $datetime = new \DateTime();
        $conditions = array(
                array('nrorg' => $row['NRORG']),
                array('nrconfirmarefe' => $row['NRCONFIRMAREFE'])
            );
        
        $confirmarefe = $this->entityManager->getRepository('\Teknisa\Model\Planejamento\Entities\Confirmarefe')
        ->findOneBy(array('nrconfirmarefe' => $row['NRCONFIRMAREFE']), array('nrconfirmarefe' => "DESC"));
        
        
        if ($confirmarefe instanceof Confirmarefe) {

            $confirmarefe->setQtcomeoriginal($row['QTCOMEORIGINAL']);
            $confirmarefe->setQtcomealterada($row['QTCOMEALTERADA']);
            $confirmarefe->setQttotalalterada($row['QTTOTALALTERADA']);
            $confirmarefe->setIdqtdeaprovada($row['IDQTDEAPROVADA']);
            $confirmarefe->setDsparametros($row['DSPARAMETROS']);
            $confirmarefe->setNrorgultatu($row['NRORG']);
            $confirmarefe->setDtultatu(new \DateTime());
            $confirmarefe->setCdoperultatu($row['CDOPERADOR']);
            $this->entityManager->persist($confirmarefe);
        }
    }
    
    public function aprovaCardapio($row){
        $confirmarefe = $this->entityManager->getRepository('\Teknisa\Model\Planejamento\Entities\Confirmarefe')
        ->findBy(array('nrorg' => $row['NRORG'],'cdfilial' => $row['CDFILIAL'],
        'cdservfili' => $row['CDSERVFILI'],'nrcardapio' => $row['NRCARDAPIO'], 'idqtdeaprovada' => $row['IDQTDEAPROVADA']));
        
        foreach ($confirmarefe as $confirmarefeItem) {
            if($confirmarefeItem instanceof Confirmarefe) {
                $confirmarefeItem->setIdqtdeaprovada('APROVADA');
                $confirmarefeItem->setNrorgultatu($row['NRORG']);
                $confirmarefeItem->setDtultatu(new \DateTime());
                $confirmarefeItem->setCdoperultatu($row['CDOPERADOR']);
                $this->entityManager->persist($confirmarefeItem);
            }
        }
    }
    
    public function reprovaCardapio($row){
        $confirmarefe = $this->entityManager->getRepository('\Teknisa\Model\Planejamento\Entities\Confirmarefe')
        ->findBy(array('nrorg' => $row['NRORG'], 'cdfilial' => $row['CDFILIAL'],
        'cdservfili' => $row['CDSERVFILI'],'nrcardapio' => $row['NRCARDAPIO'], 'idqtdeaprovada' => $row['IDQTDEAPROVADA']));
        foreach ($confirmarefe as $confirmarefeItem) {
            if($confirmarefeItem instanceof Confirmarefe) {
                $confirmarefeItem->setIdqtdeaprovada('REPROVADA');
                $confirmarefeItem->setNrorgultatu($row['NRORG']);
                $confirmarefeItem->setDtultatu(new \DateTime());
                $confirmarefeItem->setCdoperultatu($row['CDOPERADOR']);
            
                $this->entityManager->persist($confirmarefeItem);
            } 
        }
    }
}